( cd bin ; rm -rf red )
( cd bin ; ln -sf ed red )
( cd bin ; rm -rf compress )
( cd bin ; ln -sf /usr/bin/compress compress )
( cd etc/fs ; rm -rf fsck.ext2 )
( cd etc/fs ; ln -sf /sbin/e2fsck fsck.ext2 )
( cd etc/fs ; rm -rf fsck.minix )
( cd etc/fs ; ln -sf /sbin/fsck.minix fsck.minix )
( cd etc/fs ; rm -rf mkfs.ext2 )
( cd etc/fs ; ln -sf /sbin/mke2fs mkfs.ext2 )
( cd etc/fs ; rm -rf mkfs.minix )
( cd etc/fs ; ln -sf /sbin/mkfs.minix mkfs.minix )
( cd etc/fs ; rm -rf fsck.xiafs )
( cd etc/fs ; ln -sf /sbin/xfsck fsck.xiafs )
( cd etc/fs ; rm -rf mkfs.xiafs )
( cd etc/fs ; ln -sf /sbin/mkxfs mkfs.xiafs )
( cd etc/fs ; rm -rf fsck.umsdos )
( cd etc/fs ; ln -sf /bin/true fsck.umsdos )
( cd etc/fs ; rm -rf fsck.hpfs )
( cd etc/fs ; ln -sf /bin/true fsck.hpfs )
( cd etc/fs ; rm -rf fsck.msdos )
( cd etc/fs ; ln -sf /bin/true fsck.msdos )
( cd etc/fs ; rm -rf mkfs.msdos )
( cd etc/fs ; ln -sf /sbin/mkdosfs mkfs.msdos )
( cd sbin ; rm -rf rmmod )
( cd sbin ; ln -sf insmod rmmod )
( cd sbin ; rm -rf ksyms )
( cd sbin ; ln -sf insmod ksyms )
( cd sbin ; rm -rf depmod )
( cd sbin ; ln -sf modprobe depmod )
( cd . ; rm -rf usr )
( cd . ; ln -sf /cdrom/live/usr usr )
